==> alliance-5.0-20020701.tar.gz: alliance-5.0/vex/src/vexalloc.c <==
/*------------------------------------------------------------\
|                                                             |
| This file is part of the Alliance CAD System Copyright      |
| (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
|                                                             |
| Home page      : http://www-asim.lip6.fr/alliance/          |
| E-mail support : mailto:alliance-support@asim.lip6.fr       |
|                                                             |
| This progam is  free software; you can redistribute it      |
| and/or modify it under the  terms of the GNU Library General|
| Public License as published by the Free Software Foundation |
| either version 2 of the License, or (at your option) any    |
| later version.                                              |
|                                                             |
| Alliance VLSI  CAD System  is distributed  in the hope that |
| it  will be useful, but WITHOUT  ANY WARRANTY;              |
| without even the  implied warranty of MERCHANTABILITY or    |
| FITNESS FOR A PARTICULAR PURPOSE. See the GNU General       |
| Public License for more details.                            |
|                                                             |
| You should have received a copy  of the GNU General Public  |
| License along with the GNU C Library; see the file COPYING. |
| If not, write to the Free Software Foundation, Inc.,        |
| 675 Mass Ave, Cambridge, MA 02139, USA.                     |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
| Tool    :                     Vex                           |
|                                                             |
| File    :                  vexalloc.c                       |
|                                                             |
| Date    :                   03.12.96                        |
|                                                             |
| Author  :               Jacomme Ludovic                     |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                         Include Files                       |
|                                                             |
\------------------------------------------------------------*/

# include "mut.h"
# include "aut.h"
# include "vex.h"

# include <stdio.h>
# include <string.h>
# include <memory.h>
# include "vexalloc.h"
# include "vexerror.h"

/*------------------------------------------------------------\
|                                                             |
|                           Constants                         |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                            Types                            |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Variables                          |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Functions                          |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                     Vex Alloc Functions                     |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                        Vex Alloc Node                       |
|                                                             |
\------------------------------------------------------------*/

vexexpr *allocvexnode()
{
  return( (vexexpr *)autallocheap( sizeof( vexexpr ) ) );
}

/*------------------------------------------------------------\
|                                                             |
|                          Vex Copy Node                      |
|                                                             |
\------------------------------------------------------------*/

vexexpr *copyvexnode( Target, Source )

  vexexpr *Target;
  vexexpr *Source;
{
  memcpy( (char *)Target, (char *)Source, sizeof( vexexpr ) );

  return( Target );
}

/*------------------------------------------------------------\
|                                                             |
|                        Vex Duplicate Node                   |
|                                                             |
\------------------------------------------------------------*/

vexexpr *dupvexnode( Node )

  vexexpr *Node;
{
  vexexpr *DupNode;

  DupNode = (vexexpr *)autallocheap( sizeof( vexexpr ) );
  DupNode = copyvexnode( DupNode, Node );

  return( DupNode );
}

==> alliance-5.0-20060509.tar.gz: alliance-5.0/vex/src/vexalloc.c <==
/*------------------------------------------------------------\
|                                                             |
| This file is part of the Alliance CAD System Copyright      |
| (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
|                                                             |
| Home page      : http://www-asim.lip6.fr/alliance/          |
| E-mail         : mailto:alliance-users@asim.lip6.fr       |
|                                                             |
| This progam is  free software; you can redistribute it      |
| and/or modify it under the  terms of the GNU Library General|
| Public License as published by the Free Software Foundation |
| either version 2 of the License, or (at your option) any    |
| later version.                                              |
|                                                             |
| Alliance VLSI  CAD System  is distributed  in the hope that |
| it  will be useful, but WITHOUT  ANY WARRANTY;              |
| without even the  implied warranty of MERCHANTABILITY or    |
| FITNESS FOR A PARTICULAR PURPOSE. See the GNU General       |
| Public License for more details.                            |
|                                                             |
| You should have received a copy  of the GNU General Public  |
| License along with the GNU C Library; see the file COPYING. |
| If not, write to the Free Software Foundation, Inc.,        |
| 675 Mass Ave, Cambridge, MA 02139, USA.                     |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
| Tool    :                     Vex                           |
|                                                             |
| File    :                  vexalloc.c                       |
|                                                             |
| Date    :                   03.12.96                        |
|                                                             |
| Author  :               Jacomme Ludovic                     |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                         Include Files                       |
|                                                             |
\------------------------------------------------------------*/

# include "mut.h"
# include "aut.h"
# include "vex.h"

# include <stdio.h>
# include <string.h>
# include <memory.h>
# include "vexalloc.h"
# include "vexerror.h"

/*------------------------------------------------------------\
|                                                             |
|                           Constants                         |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                            Types                            |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Variables                          |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Functions                          |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                     Vex Alloc Functions                     |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                        Vex Alloc Node                       |
|                                                             |
\------------------------------------------------------------*/

vexexpr *allocvexnode()
{
  return( (vexexpr *)autallocheap( sizeof( vexexpr ) ) );
}

/*------------------------------------------------------------\
|                                                             |
|                          Vex Copy Node                      |
|                                                             |
\------------------------------------------------------------*/

vexexpr *copyvexnode( Target, Source )

  vexexpr *Target;
  vexexpr *Source;
{
  memcpy( (char *)Target, (char *)Source, sizeof( vexexpr ) );

  return( Target );
}

/*------------------------------------------------------------\
|                                                             |
|                        Vex Duplicate Node                   |
|                                                             |
\------------------------------------------------------------*/

vexexpr *dupvexnode( Node )

  vexexpr *Node;
{
  vexexpr *DupNode;

  DupNode = (vexexpr *)autallocheap( sizeof( vexexpr ) );
  DupNode = copyvexnode( DupNode, Node );

  return( DupNode );
}
